#!/bin/sh

##
## This script get the source code of Mozc from GitHub repository, 
## and generate the tarball.
##
## Last update: 2023-05-18
##

# If this vale is null, get the latest source code
SPECIFIC_COMMIT="4081973241bcd600ecc9e0dcdccc299fe53ca005"

if [ "$SPECIFIC_COMMIT" = "" ]; then
  wget https://github.com/google/mozc/archive/refs/heads/master.zip
  COMMIT_ID=$(unzip -z master.zip | sed -n 2p | cut -c 1-7)
  unzip -q master.zip
  mv -f mozc-master mozc
  rm -f master.zip
else
  wget https://github.com/google/mozc/archive/$SPECIFIC_COMMIT.zip
  COMMIT_ID=$(unzip -z $SPECIFIC_COMMIT.zip | sed -n 2p | cut -c 1-7)
  #COMMIT_ID=$(echo $SPECIFIC_COMMIT | cut -c 1-7)
  unzip -q $SPECIFIC_COMMIT.zip
  mv -f mozc-$SPECIFIC_COMMIT mozc
  rm -f $SPECIFIC_COMMIT.zip
fi

pushd mozc

# get the version number of Mozc
VER_TXT="src/data/version/mozc_version_template.bzl"
MAJOR=$(grep "MAJOR =" $VER_TXT | cut -c 9-)
MINOR=$(grep "MINOR =" $VER_TXT | cut -c 9-)
BUILD=$(grep "BUILD_OSS =" $VER_TXT | cut -c 13-)
#REVISION=$(grep "REVISION =" $VER_TXT | cut -c 12-)
REVISION=102
MOZC_VER="$MAJOR.$MINOR.$BUILD.$REVISION.$COMMIT_ID"

# remove unneeded files and directories
#rm -rf .github
#rm -rf docker
rm -rf src/third_party/*

popd

# rename directory with version number
[ -d mozc-$MOZC_VER ] && mv -f mozc-$MOZC_VER mozc-$MOZC_VER.old
mv mozc mozc-$MOZC_VER

# generate tarball
echo ""
echo "Now generating mozc-$MOZC_VER.tar.xz"
echo "Please wait for a while....."
[ -f mozc-$MOZC_VER.tar.xz ] && mv -f mozc-$MOZC_VER.tar.xz mozc-$MOZC_VER.tar.xz.old
tar -caf mozc-$MOZC_VER.tar.xz mozc-$MOZC_VER
echo ""
echo "Completed."
echo ""


exit 0
